==> org.Ce.eg.db_2.2.6.tar.gz: org.Ce.eg.db/man/org.Ce.eg_dbconn.Rd <==
\name{org.Ce.eg_dbconn}

\alias{org.Ce.eg_dbconn}
\alias{org.Ce.eg_dbfile}
\alias{org.Ce.eg_dbschema}
\alias{org.Ce.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.Ce.eg_dbconn()
  org.Ce.eg_dbfile()
  org.Ce.eg_dbschema(file="", show.indices=FALSE)
  org.Ce.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.Ce.eg_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{org.Ce.eg_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{org.Ce.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.Ce.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.Ce.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.Ce.eg_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{org.Ce.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.Ce.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.Ce.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.Ce.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.Ce.eg_dbconn() was created with:
  dbConnect(SQLite(), dbname=org.Ce.eg_dbfile(), cache_size=64000, synchronous=0)

  org.Ce.eg_dbschema()

  org.Ce.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> org.Ce.eg.db_2.7.1.tar.gz: org.Ce.eg.db/man/org.Ce.eg_dbconn.Rd <==

\name{org.Ce.eg_dbconn}

\alias{org.Ce.eg_dbconn}
\alias{org.Ce.eg_dbfile}
\alias{org.Ce.eg_dbschema}
\alias{org.Ce.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.Ce.eg_dbconn()
  org.Ce.eg_dbfile()
  org.Ce.eg_dbschema(file="", show.indices=FALSE)
  org.Ce.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.Ce.eg_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{org.Ce.eg_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{org.Ce.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.Ce.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.Ce.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.Ce.eg_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{org.Ce.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.Ce.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.Ce.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.Ce.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.Ce.eg_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=org.Ce.eg_dbfile(), cache_size=64000,
  synchronous=0)

  org.Ce.eg_dbschema()

  org.Ce.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
